@@ -42,8 +42,8 @@ class PromptEnhancerCLI:
             "gentle": {
                 "name": "Gentle",
                 "color": "#90EE90",
-                "description": "Light syntax, grammar and clarity improvements without changing tone",
-                "prompt": "Gently improve the syntax, grammar and clarity of this prompt while maintaining the original tone and intent. Fix language errors and make it more precise, but don't significantly change the content. Return ONLY the enhanced prompt."
+                "description": "Creates a polished, professional prompt while preserving the original intent",
+                "prompt": "Transform this prompt into a clear, well-structured, and professional version while keeping the same core request. Fix grammar, improve word choice, add useful context or format specifications, and make it sound polished and articulate. Keep it concise but elevate the language quality and clarity. Maintain the original intent but present it in a more refined way. Return ONLY the enhanced prompt."
             },
             "structured": {
                 "name": "Structured", 
@@ -136,10 +136,24 @@ class PromptEnhancerCLI:
         
         completer = CommandAndFileCompleter()
         
+        # Create key bindings for custom Enter behavior
+        bindings = KeyBindings()
+        
+        @bindings.add('enter')
+        def _(event):
+            """Submit on Enter"""
+            event.app.exit(result=event.app.current_buffer.text)
+        
+        @bindings.add('escape', 'enter')  # Alt+Enter
+        def _(event):
+            """New line on Alt+Enter"""
+            event.current_buffer.insert_text('\n')
+        
         # Create prompt session with multiline support for main prompts
         self.prompt_session = PromptSession(
             multiline=True,
-            completer=completer
+            completer=completer,
+            key_bindings=bindings
         )
         
         # Create single-line prompt session for configuration inputs
@@ -216,8 +230,8 @@ class PromptEnhancerCLI:
             f"[dim]{subtitle}[/dim]\n\n"
             "[bold]How to use:[/bold]\n"
             "• Enter your prompt and get an enhanced version\n"
-            "• [yellow]Enter[/yellow] - New line\n"
-            "• [yellow]Meta+Enter[/yellow] - Process prompt\n\n"
+            "• [yellow]Enter[/yellow] - Process prompt\n"
+            "• [yellow]Alt+Enter[/yellow] - New line\n\n"
             "[bold]Available commands:[/bold]\n"
             "• [green]/help[/green] - Show detailed help\n"
             "• [green]/style[/green] - Change enhancement style\n"
